@@ -15,8 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains a Apache Beam Hook."""
-
 from __future__ import annotations
 
 import asyncio
@@ -37,13 +35,9 @@ from typing import TYPE_CHECKING
 from packaging.version import Version
 
 from airflow.exceptions import AirflowConfigException, AirflowException
+from airflow.providers.apache.beam.version_compat import BaseHook
 from airflow.providers.common.compat.standard.utils import prepare_virtualenv
 
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
-
 if TYPE_CHECKING:
     import logging
 
